@@ -1,8 +1,8 @@
-__version__ = "0.0.2"
+__version__ = "0.4.0"
 
-from .client import Client
+from .client import Client, ClientProxySettings, ClientProxyType
 from .filters import FilterCallable
 from .handlers import Handler, HandlerCallable
 from .middlewares import MiddlewareCallable
 from .tdjson import TDJson, TDLibLogVerbosity
-from .utils import ainput, AsyncResult, str_to_base64
+from .utils import ainput, PendingRequest, str_to_base64
